@@ -1,14 +1,16 @@
 package Perinci::CmdLine::Inline;
 
-our $DATE = '2017-01-06'; # DATE
-our $VERSION = '0.41'; # VERSION
+our $DATE = '2017-01-09'; # DATE
+our $VERSION = '0.42'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 use Log::Any::IfLOG qw($log);
 
+use Data::Clean::JSON;
 use Data::Dmp;
+use JSON::MaybeXS ();
 use Module::CoreList::More;
 use Module::Path::More qw(module_path);
 
@@ -982,7 +984,6 @@ _
 _
 
         {
-            require Data::Clean::JSON;
             my $cleanser = Data::Clean::JSON->get_cleanser;
             my $src = $cleanser->{src};
             $cd->{module_srcs}{'Local::_pci_clean_json'} = "require Scalar::Util; use feature 'state'; sub _pci_clean_json { state \$cleanser = $src; \$cleanser->(shift) }\n1;\n";
@@ -1143,7 +1144,6 @@ _
             ("### code_after_shebang\n", $args{code_after_shebang}, "\n") x !!$args{code_after_shebang},
 
             "# PERICMD_INLINE_SCRIPT: ", do {
-                require JSON::MaybeXS;
                 my %tmp = %args;
                 # don't show the potentially long/undumpable argument values
                 for (grep {/^code_/} keys %tmp) {
@@ -1152,6 +1152,12 @@ _
                 JSON::MaybeXS::encode_json(\%tmp);
             }, "\n\n",
 
+            "# PERICMD_INLINE_SCRIPT_METAS: ", do {
+                my $metas = Data::Clean::JSON->get_cleanser->clone_and_clean(
+                    $cd->{metas});
+                JSON::MaybeXS::encode_json($metas);
+            }, "\n\n",
+
             "# This script is generated by ", __PACKAGE__,
             " version ", (${__PACKAGE__."::VERSION"} // 'dev'), " on ",
             scalar(localtime), ".\n\n",
@@ -1250,7 +1256,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.41 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2017-01-06.
+This document describes version 0.42 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2017-01-09.
 
 =head1 SYNOPSIS
 
